Turq user manual
================

Turq is a small HTTP server that can be scripted in a Python-based language.
Use it to set up mock HTTP resources that respond with the status, headers,
and body of your choosing. Turq is designed for quick interactive testing,
but can be used in automated scenarios as well.


.. toctree::
   :maxdepth: 2

   guide
   examples
   history
